==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFilteringEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDetailDescription } from "./WebFilteringEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFilteringEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringEventArgsDetailDescriptionMetadata.a == null) {
                WebFilteringEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringEventArgsDetailDescriptionMetadata.c(WebFilteringEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebFilteringEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringEventArgsDetailDescriptionMetadata.a);
            WebFilteringExpressionsTreeDescriptionMetadata.d(a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FilteringEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("FilteringExpressions", "ExportedType:WebFilteringExpressionsTree");
        }
        static d(a) {
            WebFilteringEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebFilteringEventArgsDetail", () => new WebFilteringEventArgsDetailDescription());
            a.z("WebFilteringEventArgsDetail", WebFilteringEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFilteringEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringEventArgsDetailDescriptionMetadata, 'WebFilteringEventArgsDetailDescriptionMetadata');
    WebFilteringEventArgsDetailDescriptionMetadata.a = null;
    return WebFilteringEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDetailDescription } from "./WebFilteringEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFilteringEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringEventArgsDetailDescriptionMetadata.a == null) {
                WebFilteringEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringEventArgsDetailDescriptionMetadata.c(WebFilteringEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebFilteringEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringEventArgsDetailDescriptionMetadata.a);
            WebFilteringExpressionsTreeDescriptionMetadata.d(a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FilteringEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FilteringExpressions", "ExportedType:WebFilteringExpressionsTree");
        }
        static d(a) {
            WebFilteringEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebFilteringEventArgsDetail", () => new WebFilteringEventArgsDetailDescription());
            a.ab("WebFilteringEventArgsDetail", WebFilteringEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFilteringEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringEventArgsDetailDescriptionMetadata, 'WebFilteringEventArgsDetailDescriptionMetadata');
    WebFilteringEventArgsDetailDescriptionMetadata.a = null;
    return WebFilteringEventArgsDetailDescriptionMetadata;
})();
